<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="html"/>

<!--
* Roland S. Kamzelak 8.1.2003
* www.kamzelak.de
** Zweck: Briefedition Harry Graf Kessler an Richard und Ida Dehmel
* Dissertationsprojekt (Universitaet Tuebingen)
*
** Bearbeiter: Roland S. Kamzelak
*
** Dateiformat: XSL
*
** weitere Dateien: briefed.dtd, briefed.css
*
* Sonstige Hinweise:
* - emph-Formatierung ist noch zu klren! Jetzt in der XSL-Datei als <u> (12.1.2003 ka)
* - Loesung fuer <signed rend="integrated"> und <salute rend="integrated">? (13.1.2003 ka)
*
* Revisionen:
* 3.0 - 29.4.2003: Link-Struktur hinzugeguegt. rsk
* 2.0 - 27.4.2003: kleinere Korrekturen. rsk
* 1.0 - 8.1.2003: Ausgangsversion. rsk
*
**
-->

     <!-- Wurzelelement, Kopf, Ueberschrift -->

<xsl:template match="/">
 <html>
 <head>
 <link rel="stylesheet" type="text/css" href="dtd/briefed.css" media="screen"></link>
 <link rel="stylesheet" type="text/css" href="dtd/briefedp.css" media="print"></link>
 <title>
   <xsl:value-of select="//titleStmt/title"/>
 </title>
 </head>
 <body>
  <xsl:apply-templates/>
 </body>
 </html>
</xsl:template>

<xsl:template match="fileDesc">
   <span style="background-color: white">
     <h1><xsl:value-of select="titleStmt/title"/></h1>
     <!--<xsl:value-of select="publicationStmt/p"/>-->
     <!--<xsl:value-of select="sourceDesc/p"/>-->
   </span>
</xsl:template>

<xsl:template match="revisionDesc">
   <span style="background-color: white">
     <!--><xsl:value-of select="change"/>-->
   </span>
</xsl:template>

     <!-- Default-Template: alles rot, was kein spezielles Template hat -->

<xsl:template match="*">
   <span style="background-color: red; font-family: Arial">
     <xsl:apply-templates/>
   </span>
</xsl:template>


     <!-- Differenzierte Templates -->

     <!-- DIV-->

<xsl:template match="div">
 <span style="background-color: white; font-family: Verdana; font-size: small">
   <p style="font-size:8pt; margin-top=24pt; margin-bottom=8pt; margin-left=60pt; line-height=9pt">resp: <xsl:value-of select="head/note[@type='resp']"/> |
         transcription: <xsl:value-of select="head/note[@type='transcription']"/> |
         orig: <xsl:value-of select="head/note[@type='orig']"/> |
         kind: <xsl:value-of select="head/note[@type='kind']"/> |
         sheets: <xsl:value-of select="head/note[@type='sheets']"/> |
         pages: <xsl:value-of select="head/note[@type='pages']"/> |
         paper: <xsl:value-of select="headnote[@type='paper']"/> |
    other: <xsl:value-of select="head/note[@type='other']"/>
   </p>
   <h2>
    <xsl:text disable-output-escaping="yes">&lt;a name=&quot;</xsl:text>
    <xsl:value-of select='substring(@n,1,5)'/>
    <xsl:text  disable-output-escaping="yes">&quot;&gt;&lt;/a&gt;</xsl:text>
    <xsl:value-of select="@n"/><br></br>
    <xsl:value-of select="docAuthor/name"/> an
    <xsl:value-of select="docAuthor/rs[@type='at']"/> -
    <xsl:value-of select="docAuthor/rs[@type='loc']"/>,
    <xsl:value-of select="docDate/date"/>
   </h2>
   <xsl:apply-templates/>
 </span>
</xsl:template>


<!-- HEAD -->

<xsl:template match="head">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="note">
 <!--<xsl:apply-templates/>-->
</xsl:template>

<xsl:template match="figure">
 <xsl:if test="string-length() &gt; 0">
  <xsl:text disable-output-escaping="yes">&lt;a href=&quot;images/</xsl:text>
  <xsl:value-of select="@n"/>
  <xsl:text disable-output-escaping="yes">&quot; target=&quot;bild&quot;&gt;</xsl:text>
  <xsl:text disable-output-escaping="yes">&lt;img src=&quot;images/t</xsl:text>
  <xsl:value-of select="@n"/>
  <xsl:text disable-output-escaping="yes">&quot;&gt;&lt;/a&gt;</xsl:text>
 </xsl:if>
</xsl:template>

     <!-- DOCAUTHOR -->

<xsl:template match="docAuthor">
 <span>
  <!--<xsl:value-of select="docAuthor/name"/> -->
 </span>
</xsl:template>

     <!-- DOCDATE -->

<xsl:template match="docDate">
 <span>
  <!--<xsl:value-of select="docDate/date"/> -->
 </span>
</xsl:template>

     <!-- SALUTE -->

<xsl:template match="salute">
 <span style="background-color: white; font-family: Verdana; margin-bottom: 12em">
  <xsl:if test="@rend=''">
   <p>
    <xsl:value-of select="salute"/>
   </p>
  <xsl:apply-templates/>
 </xsl:if>
 </span>

 <xsl:if test="@rend='integrated'">
 <p></p>
 <xsl:value-of select="salute"/>
  <xsl:text> </xsl:text>
  <xsl:apply-templates/>
 </xsl:if>
</xsl:template>

     <!-- P -->

<xsl:template match="p">
 <span style="background-color: white; font-family: Verdana">
   <p><xsl:apply-templates/></p>
 </span>
</xsl:template>

<xsl:template match="p[@rend='center']">
  <span style="background-color: white; font-family: Verdana">
    <p align="center"><xsl:apply-templates/></p>
  </span>
</xsl:template>

<xsl:template match="p[@rend='1']">
  <span style="background-color: white; font-family: Verdana">
    <p.1><xsl:apply-templates/></p.1>
  </span>
</xsl:template>

     <!-- SIGNED -->

<xsl:template match="signed">
 <span style="background-color: white">
   <p><xsl:value-of select="signed"/></p>
    <xsl:apply-templates/>
 </span>
</xsl:template>

<xsl:template match="signed[@rend='center']">
 <span style="background-color: white">
   <p align="center"><xsl:apply-templates/></p>
 </span>
 </xsl:template>

      <!-- OPENER -->

<xsl:template match="opener">
 <span style="background-color: white; font-family: Verdana">
  <p><xsl:value-of select="opener"/></p>
  <xsl:apply-templates/>
 </span>
</xsl:template>

     <!-- DATELINE -->

<xsl:template match="dateline">
 <span style="background-color: white; font-family: Verdana; margin-bottom: 12em">
   <p><xsl:value-of select="dateline"/></p>
   <xsl:apply-templates/>
 </span>
</xsl:template>

     <!-- TRAILER -->

<xsl:template match="trailer[@rend='left']">
 <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="trailer[@rend='left']/name">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="trailer[@rend='center']">
 <p align="center">
  <xsl:apply-templates/>
 </p>
</xsl:template>

<xsl:template match="trailer[@rend='integrated']">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="trailer[@rend='note']">
 <p></p>
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="trailer[@rend='note']/emph/note/p">
 <p style="font-size: 12pt; line-height: 14pt"><xsl:apply-templates/></p>
</xsl:template>

     <!-- Allgemeine Elemente -->

<xsl:template match="emph[@lang='greek']">
 <i><xsl:apply-templates/></i>
</xsl:template>

<xsl:template match="emph[@lang='french']">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="emph[@lang='english']">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="emph[@lang='spanish']">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="emph[@lang='latin']">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="emph[@rend='note']">
 <p style="line-height:8pt"><i><xsl:apply-templates/></i></p>
</xsl:template>

<xsl:template match="seg">
 <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="seg/title">
 <h3><xsl:apply-templates/></h3>
</xsl:template>

<xsl:template match="seg/name">
  <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="pb">
 [<xsl:value-of select="@n"/>]
</xsl:template>

<xsl:template match="lb">
 <br><xsl:value-of select="lb"/></br>
</xsl:template>

<xsl:template match="emph">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="emph[@rend='u1']">
 <u><xsl:apply-templates/></u>
</xsl:template>

<xsl:template match="emph[@rend='u2']">
 <u><xsl:apply-templates/></u>
</xsl:template>

<xsl:template match="emph[@rend='u3']">
 <u><xsl:apply-templates/></u>
</xsl:template>

<xsl:template match="emph[@rend='sup']">
 <sup><xsl:apply-templates/></sup>
</xsl:template>

<xsl:template match="hi[@rend='u1']">
 <u><xsl:apply-templates/></u>
</xsl:template>

<xsl:template match="hi[@rend='u2']">
 <u style="color:green"><xsl:apply-templates/></u>
</xsl:template>

<xsl:template match="hi[@rend='u3']">
 <u style="color:red"><xsl:apply-templates/></u>
</xsl:template>

<xsl:template match="hi[@rend='space']">
 <u><xsl:apply-templates/></u>
</xsl:template>

<xsl:template match="hi[@rend='sup']">
 <sup><xsl:apply-templates/></sup>
</xsl:template>

<xsl:template match="hi[@rend='sub']">
 <sub><xsl:apply-templates/></sub>
</xsl:template>

<xsl:template match="name">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="unclear">
 <span style="background-color: lightgrey">
  <xsl:apply-templates/>
 </span>
</xsl:template>

<xsl:template match="add">
 {<xsl:apply-templates/>}
</xsl:template>

<xsl:template match="del">
 <s><xsl:apply-templates/></s>
</xsl:template>

<xsl:template match="rs[@type='per']">
 <span style="background-color: white">
  <xsl:apply-templates/>
  <xsl:text disable-output-escaping="yes">&lt;a href=&quot;persreg.html#</xsl:text>
  <xsl:value-of select='@key'/>
  <xsl:text disable-output-escaping="yes">&quot;&gt;</xsl:text>
  <sup>{<xsl:value-of select="@key"/>}</sup>
  <xsl:text disable-output-escaping="yes">&lt;/a&gt;</xsl:text>
 </span>
</xsl:template>

<xsl:template match="rs[@type='wrk']">
 <span style="background-color: white">
  <xsl:apply-templates/>
  <xsl:text disable-output-escaping="yes">&lt;a href=&quot;persreg.html#</xsl:text>
  <xsl:value-of select='@key'/>
  <xsl:text disable-output-escaping="yes">&quot;&gt;</xsl:text>
  <sup>{<xsl:value-of select="@key"/>}</sup>
  <xsl:text disable-output-escaping="yes">&lt;/a&gt;</xsl:text>
 </span>
</xsl:template>

<xsl:template match="rs[@type='loc']">
 <span style="background-color: white">
  <xsl:apply-templates/>
  <xsl:text disable-output-escaping="yes">&lt;a href=&quot;ortsreg.html#</xsl:text>
  <xsl:value-of select='@key'/>
  <xsl:text disable-output-escaping="yes">&quot;&gt;</xsl:text>
  <sup>{<xsl:value-of select="@key"/>}</sup>
  <xsl:text disable-output-escaping="yes">&lt;/a&gt;</xsl:text>
 </span>
</xsl:template>

<xsl:template match="rs[@type='other']">
  <xsl:apply-templates/>
</xsl:template>


<xsl:template match="note[@type='reg']">
 [ <xsl:apply-templates/> ]
</xsl:template>

<xsl:template match="rs[@key='']">
 <span style="background-color: yellow"><xsl:apply-templates/><sup>{____}</sup></span>
</xsl:template>

<xsl:template match="note[@type='com']">
 [<i><xsl:apply-templates/></i>]
</xsl:template>

</xsl:stylesheet>